diff --git a/applications/nrf5340_audio/broadcast_source/CMakeLists.txt b/applications/nrf5340_audio/broadcast_source/CMakeLists.txt
index 5c48ca62e..28847d66c 100644
--- a/applications/nrf5340_audio/broadcast_source/CMakeLists.txt
+++ b/applications/nrf5340_audio/broadcast_source/CMakeLists.txt
@@ -3,6 +3,7 @@
 #
 # SPDX-License-Identifier: LicenseRef-Nordic-5-Clause
 #
 
 target_sources(app PRIVATE
+	       ${CMAKE_CURRENT_SOURCE_DIR}/config.c
 	       ${CMAKE_CURRENT_SOURCE_DIR}/main.c)
diff --git a/applications/nrf5340_audio/broadcast_source/main.c b/applications/nrf5340_audio/broadcast_source/main.c
index fb88d73d6..8596deb88 100644
--- a/applications/nrf5340_audio/broadcast_source/main.c
+++ b/applications/nrf5340_audio/broadcast_source/main.c
@@ -566,7 +566,10 @@ int main(void)
 	/* Start broadcaster */
 	ret = bt_mgmt_adv_start(0, ext_adv_buf[0], ext_adv_buf_cnt, &per_adv_buf[0],
 				per_adv_buf_cnt, false);
 	ERR_CHK_MSG(ret, "Failed to start first advertiser");
 
+	ret = bt_config_adv_start();
+	ERR_CHK_MSG(ret, "Failed to start advertiser for configuration");
+
 	return 0;
 }
diff --git a/applications/nrf5340_audio/prj.conf b/applications/nrf5340_audio/prj.conf
index 65b79447d..2bef674f5 100644
--- a/applications/nrf5340_audio/prj.conf
+++ b/applications/nrf5340_audio/prj.conf
@@ -4,10 +4,11 @@
 # SPDX-License-Identifier: LicenseRef-Nordic-5-Clause
 #
 
 # nRF5340 Audio
 CONFIG_NRF5340_AUDIO=y
+CONFIG_TRANSPORT_BIS=y
 
 CONFIG_SAMPLE_RATE_CONVERTER=y
 CONFIG_SAMPLE_RATE_CONVERTER_FILTER_SIMPLE=y
 
 # General
@@ -33,21 +34,21 @@ CONFIG_LOG_BUFFER_SIZE=4096
 # Use this for debugging thread usage
 #CONFIG_LOG_THREAD_ID_PREFIX=y
 
 # Console related defines
 CONFIG_CONSOLE=y
-CONFIG_RTT_CONSOLE=y
+CONFIG_RTT_CONSOLE=n
 CONFIG_UART_CONSOLE=y
 
 # Shell related defines
 CONFIG_SHELL=y
 CONFIG_KERNEL_SHELL=y
 CONFIG_USE_SEGGER_RTT=y
 ## Disable logs on RTT
-CONFIG_SHELL_RTT_INIT_LOG_LEVEL_NONE=y
-CONFIG_SHELL_BACKEND_RTT=y
-CONFIG_SHELL_BACKEND_SERIAL=n
+# CONFIG_SHELL_RTT_INIT_LOG_LEVEL_NONE=y
+CONFIG_SHELL_BACKEND_RTT=n
+CONFIG_SHELL_BACKEND_SERIAL=y
 CONFIG_SHELL_VT100_COMMANDS=y
 CONFIG_SHELL_VT100_COLORS=y
 CONFIG_SHELL_STACK_SIZE=4096
 CONFIG_SHELL_CMD_BUFF_SIZE=128
 ## Reduce shell memory usage
@@ -68,5 +69,24 @@ CONFIG_DEVICE_SHELL=n
 # assume card is in slot. Thus error message is always shown if card is not inserted
 CONFIG_SD_LOG_LEVEL_OFF=y
 
 # Suppress LOG_INF messages from hci_core
 CONFIG_BT_HCI_CORE_LOG_LEVEL_WRN=y
+# CONFIG_BT_AUDIO_MAX_TRANSPORT_LATENCY_MS=40
+# CONFIG_BT_AUDIO_PRESENTATION_DELAY_US=5000
+
+# Bluetooth
+CONFIG_WDT_CTLR=y
+CONFIG_BT_PERIPHERAL=y
+CONFIG_BT_EXT_ADV_MAX_ADV_SET=3
+CONFIG_BT_PER_ADV_SYNC_TRANSFER_RECEIVER=y
+CONFIG_BT_DEVICE_NAME_GATT_WRITABLE=y
+CONFIG_DEVICE_NAME_GATT_WRITABLE_ENCRYPT=n
+CONFIG_DEVICE_NAME_GATT_WRITABLE_AUTHEN=n
+CONFIG_BT_AUDIO_RETRANSMITS=4
+CONFIG_BT_AUDIO_MAX_TRANSPORT_LATENCY_MS=100
+CONFIG_BT_AUDIO_PRESENTATION_DELAY_US=40000
+CONFIG_BT_DEVICE_NAME_DYNAMIC=y
+CONFIG_BLE_ACL_CONN_INTERVAL=80
+CONFIG_BLE_ACL_CONN_INTERVAL_SLOW=120
+CONFIG_BLE_ACL_SLAVE_LATENCY=1
+CONFIG_BLE_ACL_SUP_TIMEOUT=100
diff --git a/applications/nrf5340_audio/src/bluetooth/bt_management/bt_mgmt.c b/applications/nrf5340_audio/src/bluetooth/bt_management/bt_mgmt.c
index 85f601760..6c8110972 100644
--- a/applications/nrf5340_audio/src/bluetooth/bt_management/bt_mgmt.c
+++ b/applications/nrf5340_audio/src/bluetooth/bt_management/bt_mgmt.c
@@ -142,15 +142,10 @@ static void disconnected_cb(struct bt_conn *conn, uint8_t reason)
 	msg.conn = conn;
 
 	ret = zbus_chan_pub(&bt_mgmt_chan, &msg, K_NO_WAIT);
 	ERR_CHK(ret);
 
-	if (IS_ENABLED(CONFIG_BT_PERIPHERAL)) {
-		ret = bt_mgmt_adv_start(0, NULL, 0, NULL, 0, true);
-		ERR_CHK(ret);
-	}
-
 	/* The mutex for preventing the racing condition if two headset disconnected too close,
 	 * cause the disconnected_cb() triggered in short time leads to duplicate scanning
 	 * operation.
 	 */
 	k_mutex_lock(&mtx_duplicate_scan, K_FOREVER);
diff --git a/applications/nrf5340_audio/sysbuild/ipc_radio/prj.conf b/applications/nrf5340_audio/sysbuild/ipc_radio/prj.conf
index 57a458d24..ffe8ee1e4 100644
--- a/applications/nrf5340_audio/sysbuild/ipc_radio/prj.conf
+++ b/applications/nrf5340_audio/sysbuild/ipc_radio/prj.conf
@@ -18,10 +18,11 @@ CONFIG_BT_CTLR_ASSERT_HANDLER=y
 CONFIG_BT_ISO_PERIPHERAL=y
 CONFIG_BT_ISO_CENTRAL=y
 CONFIG_BT_ISO_BROADCASTER=y
 CONFIG_BT_ISO_SYNC_RECEIVER=y
 CONFIG_BT_EXT_ADV=y
+CONFIG_BT_EXT_ADV_MAX_ADV_SET=3
 CONFIG_BT_PER_ADV_SYNC_TRANSFER_RECEIVER=y
 CONFIG_BT_PER_ADV_SYNC_TRANSFER_SENDER=y
 
 CONFIG_BT_CTLR_CONN_ISO_GROUPS=1
 CONFIG_BT_CTLR_CONN_ISO_STREAMS=2
